
clear ; close all
FS = 12; % fontsize

SigmaMultiple = 2 ;

KsColor = [1 0 0];
HistColor = [.6 .6 0.6];
HistScale = 0.95;

TranColor = [1 0 0];
TranArea = [0.5 0.5 0.5];

TranSigma = 1/3;
WeightFun = @(X1, X2) (1/(TranSigma * sqrt(2*pi))) .* exp(-0.5 .* ((X1-X2)./TranSigma).^2);


DAT(1).data = importdata('TDP_mg.tif');
DAT(2).data = importdata('ODP_mg.tif');

DAT(1).title = 'Glassy EECO Morozovella (TDP)' ;
DAT(2).title = 'Frosty EECO Morozovella (Site 865)' ;

TRAN(1).X = [69 75]'';
TRAN(1).Y = [44 100]'';
TRAN(1).labels = {'A', ['A',char(8217)]};



TRAN(2).X = [94 68]'';
TRAN(2).Y = [21 95]'';
TRAN(2).labels = {'B', ['B',char(8217)]};

MgScale = [0 16];
MgTicks = [0:4:16];
    

figure('position',[0 1000 1000 500])


BINS = 0:16 ;

ii = 1 ;
subplot(2,4,(ii-1)*2+1)
Tdata(ii) = makeheatmap(DAT(ii),TRAN(ii)) ;
hold on
text(3,1,'A)','fontsize',20,'color',[1 1 1]) ;


title(DAT(ii).title,'fontsize',FS)

subplot(2,4,(ii-1)*2+5)
TranX = linspace(min(Tdata(ii).X),max(Tdata(ii).X),1000) ;
clear RES
for i = 1:length(Tdata(ii).dat)
    weight = WeightFun(Tdata(ii).X(i),Tdata(ii).X);
    Weight = sum(weight);
    RES(i) = Tdata(ii).dat(i) - sum(Tdata(ii).dat .* weight/Weight);
end

for i = 1:length(TranX)
    clear weight
    weight = WeightFun(TranX(i),Tdata(ii).X);

    Weight = sum(weight);
  
    TranY(i) = sum(Tdata(ii).dat .* weight/Weight);
    
    TranS(i) = SigmaMultiple*sqrt(sum((RES.*weight).^2) / Weight);
end



fill([TranX,fliplr(TranX)],[TranY+TranS,fliplr(TranY-TranS)],TranArea,'edgecolor',TranArea)
hold on
plot(TranX,TranY,'color',TranColor,'linewidth',2)


plot(Tdata(ii).X,Tdata(ii).dat,'.','color','k')



ylim(MgScale)
ylabel('Mg/Ca (mmol/mol)','fontsize',FS)
yticks(MgTicks)
xlabel('distance (µm)')
xticks(0:10:100)
ax1(ii) = gca;
set(ax1(ii),'XLim',[0 max(Tdata(ii).X)],'fontsize',FS,'fontname','arial');
text(ax1(ii).XLim(1)+2*range(ax1(ii).XLim)/100,14.5,'B)','fontsize',20,'color',[0 0 0])




subplot(2,4,(ii-1)*2+6)
[A B] = histcounts(Tdata(ii).dat,BINS) ;
A = HistScale * A/max(A);
for jj = 1:length(A)
    fill([0 A(jj) A(jj) 0],[B(jj),B(jj),B(jj+1),B(jj+1)],HistColor)
    hold on
end
yticks([])
xticks([])
axis

[A B] = ksdensity(Tdata(ii).dat) ;
A = HistScale * A/max(A);
plot(A,B,'color',KsColor,'linewidth',2)
ylim(MgScale)
yticks([])
xticks([])
AX1(ii) = gca ;
text(AX1(ii).XLim(1)+7*range(AX1(ii).XLim)/100,14.5,'C)','fontsize',20,'color',[0 0 0])



ii = 2;
subplot(2,4,(ii-1)*2+1)
Tdata(ii) = makeheatmap(DAT(ii),TRAN(ii)) ;
hold on
text(3,1,'D)','fontsize',20,'color',[1 1 1]) ;


title(DAT(ii).title,'fontsize',FS)

subplot(2,4,(ii-1)*2+5)
TranX = linspace(min(Tdata(ii).X),max(Tdata(ii).X),1000) ;
clear RES
for i = 1:length(Tdata(ii).dat)
    weight = WeightFun(Tdata(ii).X(i),Tdata(ii).X);
    Weight = sum(weight);
    RES(i) = Tdata(ii).dat(i) - sum(Tdata(ii).dat .* weight/Weight);
end

for i = 1:length(TranX)
    clear weight
    weight = WeightFun(TranX(i),Tdata(ii).X);

    Weight = sum(weight);
  
    TranY(i) = sum(Tdata(ii).dat .* weight/Weight);
    
    
    TranS(i) = SigmaMultiple*sqrt(sum((RES.*weight).^2) / Weight);
end



fill([TranX,fliplr(TranX)],[TranY+TranS,fliplr(TranY-TranS)],TranArea,'edgecolor',TranArea)
hold on
plot(TranX,TranY,'color',TranColor,'linewidth',2)


plot(Tdata(ii).X,Tdata(ii).dat,'.','color','k')



ylim(MgScale)
ylabel('Mg/Ca (mmol/mol)','fontsize',FS)
yticks(MgTicks)
xlabel('distance (µm)')
xticks(0:10:100)
ax1(ii) = gca;
set(ax1(ii),'XLim',[0 max(Tdata(ii).X)],'fontsize',FS,'fontname','arial');
text(ax1(ii).XLim(1)+2*range(ax1(ii).XLim)/100,14.5,'E)','fontsize',20,'color',[0 0 0])




subplot(2,4,(ii-1)*2+6) ;
[A , B] = histcounts(Tdata(ii).dat,BINS) ;
A = HistScale * A/max(A);
for jj = 1:length(A)
    fill([0 A(jj) A(jj) 0],[B(jj),B(jj),B(jj+1),B(jj+1)],HistColor)
    hold on
end
yticks([])
xticks([])
axis

[A , B] = ksdensity(Tdata(ii).dat) ;
A = HistScale * A/max(A);
plot(A,B,'color',KsColor,'linewidth',2)
ylim(MgScale);
yticks([]);
xticks([]);
AX1(ii) = gca ;
text(AX1(ii).XLim(1)+7*range(AX1(ii).XLim)/100,14.5,'F)','fontsize',20,'color',[0 0 0]);


%% Rescale all subplots

x_width = [0.07 0.33 0.08] ;
y_width = [0.025 .7 0.025 0.225 0.08] ;



subplot(2,4,6)
set(gca,'position',[x_width(1)+x_width(2),y_width(5),x_width(3),y_width(4)+0.05])
subplot(2,4,5)
set(gca,'position',[x_width(1),y_width(5),x_width(2),y_width(4)+0.05])

ax2(1) = axes('Position',ax1(1).Position,...
           'XAxisLocation','top',...
           'YAxisLocation','right',...
           'Color','none',...
           'XColor','black','YColor','black');

set(ax2(1),'XLim',[0 1],'YLim',ax1(1).YLim,'fontsize',20,'fontname','arial');
xticks([0 1]);
yticks([]);
xticklabels(TRAN(1).labels)

subplot(2,4,8)
set(gca,'position',[0.5+x_width(1)+x_width(2),y_width(5),x_width(3),y_width(4)+0.05])
subplot(2,4,7)
set(gca,'position',[0.5+x_width(1),y_width(5),x_width(2),y_width(4)+0.05])

ax2(2) = axes('Position',ax1(2).Position,...
           'XAxisLocation','top',...
           'YAxisLocation','right',...
           'Color','none',...
           'XColor','black','YColor','black');

set(ax2(2),'XLim',[0 1],'YLim',ax1(2).YLim,'fontsize',20,'fontname','arial');
xticks([0 1]);
yticks([]);
xticklabels(TRAN(2).labels);



subplot(2,4,1)
set(gca,'position',[0.025,y_width(3)+y_width(4)+y_width(5),x_width(2)+x_width(1)-0.02,y_width(2)])



subplot(2,4,3)
set(gca,'position',[0.5+0.025,y_width(3)+y_width(4)+y_width(5),x_width(2)+x_width(1)-0.02,y_width(2)])

set(gcf,'color','white','position',[0 1000 600 500])
set(gcf, 'InvertHardCopy', 'off');

saveas(gcf,'Figure1.svg')
