function[tdata] = makeheatmap(DAT,TRAN)

FS = 12; % fontsize

dat = DAT.data ;
Cmap = (0.1+0.9*hot(255).^0.5) ;

CmapX = linspace(0,1,length(Cmap));

SQdim = 140 ;

rescale = [0 16] ;

ColorIm = zeros(SQdim,SQdim,3);

PixelScale = 0.9;


slope = (TRAN.Y(1)-TRAN.Y(2))/(TRAN.X(1)-TRAN.X(2));


[NX NY] = size(dat);

data = zeros(NX,NY);

SQdim = max(NX,NY) ;

count  = 0;
for x = 1:NX
    for y = 1:NY
        
        I = (dat(x,y)-rescale(1))/range(rescale);%Intensity
        if I < 1 & I > 0
            ColorIm(x,y,1) = interp1(CmapX,Cmap(:,1),I);
            ColorIm(x,y,2) = interp1(CmapX,Cmap(:,2),I);
            ColorIm(x,y,3) = interp1(CmapX,Cmap(:,3),I);
        end
        if I >= 1
            ColorIm(x,y,:) = (Cmap(end,:));
        end
        if I <= 0
            ColorIm(x,y,:) = Cmap(1,:);
        end
        if I == inf
            ColorIm(x,y,:) = [0 0 0];
        end
        
        count = count+1;
        
        xx(count) = y;
        yy(count) = x;
        lindw(count,1) = x-TRAN.X(1);
        lindw(count,2) = y-TRAN.Y(1);

        lindat(count) = 0;
        
        if dat(x,y) == inf
        else
            data(x,y) = dat(x,y);
            lindat(count) = dat(x,y);
            
            
        end
        
        
    end
end


TRAN.w = 2; % width of transect (perp to direction)

theta = atan(slope); % Angle of the transect (in radians)
if slope<0
    theta = theta+pi; % 
end

rot = [cos(theta) -sin(theta)
       sin(theta) cos(theta)]; % rotation matrix for data
   
   lindw = lindw*rot;
   linx = lindw(:,1)';
   lind = lindw(:,2)';
   
   
   USE = abs(lind) <= TRAN.w & lindat>0;
   
   tdata.X = linx(USE)-min(linx(USE));
   tdata.dat = lindat(USE);
   
%% generate heatmap figure
hm = image(ColorIm);
colormap(Cmap);
set(gca,'color',[0 0 0])
hold on
xticks([])
yticks([])

axis equal

%% draw transect line
plot(TRAN.Y,TRAN.X,'linewidth',2,'color','white');
text(TRAN.Y(1)-6,TRAN.X(1),TRAN.labels(1),'color',[1 1 1],'fontsize',FS)
text(TRAN.Y(2)+1,TRAN.X(2),TRAN.labels(2),'color',[1 1 1],'fontsize',FS)



%Scalebar
SBL = 4;
SBH = 50;
SBstart = [10 15];
XX = [SBstart(1),SBstart(1)+SBL/PixelScale,SBstart(1)+SBL/PixelScale,SBstart(1)];
YY = [SBstart(2),SBstart(2),SBstart(2)+SBH/PixelScale,SBstart(2)+SBH/PixelScale];

fill(YY,XX,[1 1 1],'edgealpha',0)
text(35,5,'50\mum','color',[1 1 1],'fontsize',FS);

cb=colorbar ;


ticks = linspace(min(rescale),max(rescale),5) ;
set(cb,'ticks',0:0.25:1,'ticklabels',ticks,'fontsize',FS);

cb.Label.String = 'Mg/Ca (mmol/mol)' ;

cb.Label.Rotation = 270;
cb.Label.VerticalAlignment = 'bottom';


hold on

end