%% Mixing calculator for 2-phase foram
% Takes bulk Mg/Ca SrCa, a fixed difference in MGCa between HMC and LMC and
% the fraction of LMC. Calculates the Mg/Ca of HMC and LMC to satisfy all
% criteria. Solves function via inversion/interpolation.


function [MgCa_1, MgCa_2] = MixingCalc(MgCa0,SrCa0,Grad,F1)

MgCaBulk = @(MgCa1) (((MgCa1+Grad) ./ (1 + MgCa1 + Grad + SrCa0) .* (1-F1)) + (MgCa1) ./ (1 + MgCa1 + SrCa0) * (F1)) ./((1) ./ (1 + MgCa1 + Grad + SrCa0) * (1-F1) + (1) ./ (1 + MgCa1 + SrCa0) .* (F1)) ;

xx = linspace(MgCa0-Grad,MgCa0+Grad,10000); % construct range of plausible values

MgCa_1 = interp1(MgCaBulk(xx),xx,MgCa0,'linear','extrap'); % interpolate along it. 
MgCa_2 = MgCa_1 + Grad;



end