function [dV] = TwoPhaseODE(t,V,EQs,sys,BC,ID)

% Every 10s of real time, output current model time.
if toc >= 10
    tic
    t
end
    
    
dV = V*0;

T = BC.T(t);

ii = 1;

phi = sys.phi;

%% Calculate equilibrium calcite
    EqMgCa = V(ID.PW.Mg(ii)) / V(ID.PW.Ca(ii)) * EQs.Kd.Mg(T) ;
    EqSrCa = V(ID.PW.Sr(ii)) / V(ID.PW.Ca(ii)) * EQs.Kd.Sr(T) ;
    EqR18O = V(ID.PW.O8(ii)) / V(ID.PW.O6(ii)) * EQs.alphaO(T) ;
    EqR13C = V(ID.PW.C3(ii)) / V(ID.PW.C2(ii)) * EQs.alphaC(T) ;
    
    MolConCarb = 1/EQs.AMU.C ; % Molar concentration of Carbonate / g CaCO3
    EqCa = MolConCarb * (1 / (1 + EqMgCa + EqSrCa)) ;
    EqMg = EqCa * EqMgCa ; 
    EqSr = EqCa * EqSrCa ;
    EqO6 = 3 * MolConCarb * (1 / (1 +EqR18O));
    EqO8 = EqO6 * EqR18O;
    EqC2 = MolConCarb * (1 / (1 + EqR13C)) ;
    EqC3 = EqC2 * EqR13C ;
    

%% Calculate diffusion terms
% Left Boundary of cell
LB.Ca = BC.Ca(t) ;
LB.Mg = BC.Mg(t) ;
LB.Sr = BC.Sr(t) ; 
LB.O6 = BC.O6(t) ; 
LB.O8 = BC.O8(t) ;
LB.C2 = BC.C2(t) ;
LB.C3 = BC.C3(t) ; 

% right boundary of cell
RB.Ca = V(ID.PW.Ca(ii)) ;
RB.Mg = V(ID.PW.Mg(ii)) ;
RB.Sr = V(ID.PW.Sr(ii)) ;
RB.O6 = V(ID.PW.O6(ii)) ;
RB.O8 = V(ID.PW.O8(ii)) ;
RB.C2 = V(ID.PW.C2(ii)) ;
RB.C3 = V(ID.PW.C3(ii)) ;

%% Solve continuity equations
R1 = sys.PR1(t)  ;
R2 = sys.PR2(t)  ;


M1 = sys.F1 * EQs.PC * (1 - phi) / (EQs.PW * phi);
M2 = (1-sys.F1) * EQs.PC * (1 - phi) / (EQs.PW * phi);

dV(ID.PW.Ca(ii)) = (LB.Ca + RB.Ca - 2*V(ID.PW.Ca(ii))) * EQs.Di.Ca(T,phi)/(sys.dX(ii)^2) + R1 * M1 * (V(ID.PC1.Ca(ii))-EqCa) + R2 * M2 * (V(ID.PC2.Ca(ii))-EqCa) ;
dV(ID.PW.Mg(ii)) = (LB.Mg + RB.Mg - 2*V(ID.PW.Mg(ii))) * EQs.Di.Mg(T,phi)/(sys.dX(ii)^2) + R1 * M1 * (V(ID.PC1.Mg(ii))-EqMg) + R2 * M2 * (V(ID.PC2.Mg(ii))-EqMg) ;
dV(ID.PW.Sr(ii)) = (LB.Sr + RB.Sr - 2*V(ID.PW.Sr(ii))) * EQs.Di.Sr(T,phi)/(sys.dX(ii)^2) + R1 * M1 * (V(ID.PC1.Sr(ii))-EqSr) + R2 * M2 * (V(ID.PC2.Sr(ii))-EqSr) ;
dV(ID.PW.O6(ii)) = (LB.O6 + RB.O6 - 2*V(ID.PW.O6(ii))) * EQs.Di.O(T,phi)/(sys.dX(ii)^2) + R1 * M1 * (V(ID.PC1.O6(ii))-EqO6) + R2 * M2 * (V(ID.PC2.O6(ii))-EqO6) ;
dV(ID.PW.O8(ii)) = (LB.O8 + RB.O8 - 2*V(ID.PW.O8(ii))) * EQs.Di.O(T,phi)/(sys.dX(ii)^2) + R1 * M1 * (V(ID.PC1.O8(ii))-EqO8) + R2 * M2 * (V(ID.PC2.O8(ii))-EqO8) ;
dV(ID.PW.C2(ii)) = (LB.C2 + RB.C2 - 2*V(ID.PW.C2(ii))) * EQs.Di.C(T,phi)/(sys.dX(ii)^2) + R1 * M1 * (V(ID.PC1.C2(ii))-EqC2) + R2 * M2 * (V(ID.PC2.C2(ii))-EqC2) ;
dV(ID.PW.C3(ii)) = (LB.C3 + RB.C3 - 2*V(ID.PW.C3(ii))) * EQs.Di.C(T,phi)/(sys.dX(ii)^2) + R1 * M1 * (V(ID.PC1.C3(ii))-EqC3) + R2 * M2 * (V(ID.PC2.C3(ii))-EqC3) ;


dV(ID.PC1.Ca(ii)) = - R1 * (V(ID.PC1.Ca(ii))-EqCa) ;
dV(ID.PC1.Mg(ii)) = - R1 * (V(ID.PC1.Mg(ii))-EqMg) ;
dV(ID.PC1.Sr(ii)) = - R1 * (V(ID.PC1.Sr(ii))-EqSr) ;
dV(ID.PC1.O6(ii)) = - R1 * (V(ID.PC1.O6(ii))-EqO6) ;
dV(ID.PC1.O8(ii)) = - R1 * (V(ID.PC1.O8(ii))-EqO8) ;
dV(ID.PC1.C2(ii)) = - R1 * (V(ID.PC1.C2(ii))-EqC2) ;
dV(ID.PC1.C3(ii)) = - R1 * (V(ID.PC1.C3(ii))-EqC3) ;

dV(ID.PC2.Ca(ii)) = - R2 * (V(ID.PC2.Ca(ii))-EqCa) ;
dV(ID.PC2.Mg(ii)) = - R2 * (V(ID.PC2.Mg(ii))-EqMg) ;
dV(ID.PC2.Sr(ii)) = - R2 * (V(ID.PC2.Sr(ii))-EqSr) ;
dV(ID.PC2.O6(ii)) = - R2 * (V(ID.PC2.O6(ii))-EqO6) ;
dV(ID.PC2.O8(ii)) = - R2 * (V(ID.PC2.O8(ii))-EqO8) ;
dV(ID.PC2.C2(ii)) = - R2 * (V(ID.PC2.C2(ii))-EqC2) ;
dV(ID.PC2.C3(ii)) = - R2 * (V(ID.PC2.C3(ii))-EqC3) ;

end